# Late bid won (R030)

The winning bid was received after the submission deadline.

## Methodology

A contracting process is flagged if:

- A valid bid's received date is after the submission deadline.
- At least one tenderer of the valid bid is the supplier of an active award.

These tenderers are also flagged.

:::{admonition} Example
:class: seealso

The submission deadline is March 15. The Public Works Department leaks information from the received bids to CorruptX Solutions, to give it a competitive advantage. CorruptX Solutions submits a bid on April 1. The Public Works Department accepts the bid and awards the contract to CorruptX Solutions.
:::

:::{admonition} Why is this a red flag?
:class: hint

A corrupt buyer can award the pre-determined bidder by disregarding the submission deadline.
:::

<small>Based on "Bids after the deadline accepted" in [*Corruption in Public Procurement: Finding the Right Indicators*](https://www.researchgate.net/publication/303359108_Corruption_in_Public_Procurement_Finding_the_Right_Indicators) and "Late submissions accepted" in [*Fraud in Public Procurement: A collection of Red Flags and Best Practices*](https://ec.europa.eu/sfc/system/files/documents/sfc-files/fraud-public-procurement-final-20122017-ares20176254403.pdf).</small>

## Output

The indicator's value is always 1.0.

If the ``--map`` command-line flag is set, the ``Maps`` key contains:

ocid_tenderer_r030
: The flagged tenderers for each flagged `ocid`.

## Configuration

The indicator is not configurable.

## Assumptions

This indicator assumes that the tenderer didn't submit another valid bid before the submission deadline; in other words, its late bid is the winning bid.

:::{note}
Is this assumption not true for your data? Does your data set the `/awards[]/relatedBid` field? Please [create an issue on GitHub](https://github.com/open-contracting/cardinal-rs/issues).
:::

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/030.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/R/030.ini --no-meta docs/examples/R/030.jsonl
{"OCID":{"F":{"R030":1.0}},"Tenderer":{"W":{"R030":1.0}}}

```
